// $Id: tuner.h,v 1.10 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-

// RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 2
// (included in the RadioActive distribution in doc/GPL) as published by
// the Free Software Foundation.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#ifndef RADIOACTIVE_TUNER_H
#define RADIOACTIVE_TUNER_H

#include <gtk--/scale.h>
#include <gtk--/adjustment.h>

class Tuner: public Gtk::HScale
{
    Gtk::Adjustment tuner_data;
public:
    Tuner (double min, double max);
    
    SigC::Signal1 <void, double> freq_changed;
    void set_freq (double freq);
    
private:
    void tuner_changed();
};

#endif /* !RADIOACTIVE_TUNER_H */
